# coding: utf-8

"""
    Event Notification Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libens
from libica.openapi.libens.api.subscriptions_api import SubscriptionsApi  # noqa: E501
from libica.openapi.libens.rest import ApiException


class TestSubscriptionsApi(unittest.TestCase):
    """SubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libens.api.subscriptions_api.SubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_subscription(self):
        """Test case for create_subscription

        Creates a subscription to an event type and defines how those events get delivered.  # noqa: E501
        """
        pass

    def test_disable_subscription(self):
        """Test case for disable_subscription

        Given a subscription id, disables the specified subscription.  # noqa: E501
        """
        pass

    def test_get_subscription(self):
        """Test case for get_subscription

        Given a subscription id, returns information about that subscription.  # noqa: E501
        """
        pass

    def test_list_subscriptions(self):
        """Test case for list_subscriptions

        Get a list of subscriptions.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
