# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libwes
from libica.openapi.libwes.api.workflows_api import WorkflowsApi  # noqa: E501
from libica.openapi.libwes.rest import ApiException


class TestWorkflowsApi(unittest.TestCase):
    """WorkflowsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libwes.api.workflows_api.WorkflowsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_workflow(self):
        """Test case for create_workflow

        Create a workflow  # noqa: E501
        """
        pass

    def test_get_workflow(self):
        """Test case for get_workflow

        Get the details of a workflow  # noqa: E501
        """
        pass

    def test_list_workflows(self):
        """Test case for list_workflows

        Get a list of workflows  # noqa: E501
        """
        pass

    def test_update_workflow(self):
        """Test case for update_workflow

        Update an existing workflow  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
