# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libtes
from libica.openapi.libtes.api.task_versions_api import TaskVersionsApi  # noqa: E501
from libica.openapi.libtes.rest import ApiException


class TestTaskVersionsApi(unittest.TestCase):
    """TaskVersionsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libtes.api.task_versions_api.TaskVersionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_task_version(self):
        """Test case for create_task_version

        Create a task version  # noqa: E501
        """
        pass

    def test_get_task_version(self):
        """Test case for get_task_version

        Get the details of a task version  # noqa: E501
        """
        pass

    def test_launch_task_run(self):
        """Test case for launch_task_run

        Launch a task version  # noqa: E501
        """
        pass

    def test_list_task_versions(self):
        """Test case for list_task_versions

        Get a list of versions  # noqa: E501
        """
        pass

    def test_update_task_version(self):
        """Test case for update_task_version

        Update task version properties  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
