# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libconsole
from libica.openapi.libconsole.api.accounts_api import AccountsApi  # noqa: E501
from libica.openapi.libconsole.rest import ApiException


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libconsole.api.accounts_api.AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_account(self):
        """Test case for get_account

        Get requested account id info require authorization Bearer token  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
