# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libgds
from libica.openapi.libgds.api.volume_configurations_api import VolumeConfigurationsApi  # noqa: E501
from libica.openapi.libgds.rest import ApiException


class TestVolumeConfigurationsApi(unittest.TestCase):
    """VolumeConfigurationsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libgds.api.volume_configurations_api.VolumeConfigurationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_volume_configuration(self):
        """Test case for create_volume_configuration

        Create a volume configuration in GDS.  # noqa: E501
        """
        pass

    def test_delete_volume_configuration(self):
        """Test case for delete_volume_configuration

        Deletes a volume configuration by Id or name  # noqa: E501
        """
        pass

    def test_get_volume_configuration(self):
        """Test case for get_volume_configuration

        Get information for the specified volume configuration name or Id  # noqa: E501
        """
        pass

    def test_list_volume_configurations(self):
        """Test case for list_volume_configurations

        Get a list of volumes  # noqa: E501
        """
        pass

    def test_validate_volume_configuration(self):
        """Test case for validate_volume_configuration

        Validate a volume configuration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
