# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libconsole
from libica.openapi.libconsole.models.account_response import AccountResponse  # noqa: E501
from libica.openapi.libconsole.rest import ApiException

class TestAccountResponse(unittest.TestCase):
    """AccountResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AccountResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libconsole.models.account_response.AccountResponse()  # noqa: E501
        if include_optional :
            return AccountResponse(
                id = '0', 
                type = '0', 
                name = '0', 
                domain = libica.openapi.libconsole.models.domain.Domain(
                    id = '0', 
                    name = '0', )
            )
        else :
            return AccountResponse(
        )

    def testAccountResponse(self):
        """Test AccountResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
