# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.input_stream_settings import InputStreamSettings  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestInputStreamSettings(unittest.TestCase):
    """InputStreamSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InputStreamSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.input_stream_settings.InputStreamSettings()  # noqa: E501
        if include_optional :
            return InputStreamSettings(
                access_pattern = 'sequential', 
                cache_size_gb = 5E+1, 
                block_size_mb = 0, 
                prefetch_blocks = 0
            )
        else :
            return InputStreamSettings(
        )

    def testInputStreamSettings(self):
        """Test InputStreamSettings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
