# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libgds
from libica.openapi.libgds.models.file_response import FileResponse  # noqa: E501
from libica.openapi.libgds.rest import ApiException

class TestFileResponse(unittest.TestCase):
    """FileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FileResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libgds.models.file_response.FileResponse()  # noqa: E501
        if include_optional :
            return FileResponse(
                id = '0', 
                name = '0', 
                volume_id = '0', 
                volume_name = '0', 
                type = '0', 
                tenant_id = '0', 
                sub_tenant_id = '0', 
                path = '0', 
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                created_by = '0', 
                time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                modified_by = '0', 
                inherited_acl = [
                    '0'
                    ], 
                urn = '0', 
                size_in_bytes = 56, 
                metadata = None, 
                is_uploaded = True, 
                archive_status = 'None', 
                time_archived = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                storage_tier = 'None', 
                e_tag = '0', 
                presigned_url = '0'
            )
        else :
            return FileResponse(
        )

    def testFileResponse(self):
        """Test FileResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
