# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libwes
from libica.openapi.libwes.models.workflow_run_history_event_list import WorkflowRunHistoryEventList  # noqa: E501
from libica.openapi.libwes.rest import ApiException

class TestWorkflowRunHistoryEventList(unittest.TestCase):
    """WorkflowRunHistoryEventList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WorkflowRunHistoryEventList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libwes.models.workflow_run_history_event_list.WorkflowRunHistoryEventList()  # noqa: E501
        if include_optional :
            return WorkflowRunHistoryEventList(
                items = [
                    libica.openapi.libwes.models.workflow_run_history_event.WorkflowRunHistoryEvent(
                        name = '0', 
                        event_id = 56, 
                        previous_event_id = 56, 
                        event_type = '0', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        # event_details = libica.openapi.libwes.models.event_details.eventDetails(),
                    )
                ],
                item_count = 56, 
                first_page_token = '0', 
                next_page_token = '0', 
                prev_page_token = '0', 
                last_page_token = '0', 
                total_item_count = 56, 
                total_page_count = 56
            )
        else :
            return WorkflowRunHistoryEventList(
        )

    def testWorkflowRunHistoryEventList(self):
        """Test WorkflowRunHistoryEventList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
