# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libwes
from libica.openapi.libwes.api.workflow_versions_api import WorkflowVersionsApi  # noqa: E501
from libica.openapi.libwes.rest import ApiException


class TestWorkflowVersionsApi(unittest.TestCase):
    """WorkflowVersionsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libwes.api.workflow_versions_api.WorkflowVersionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_workflow_version(self):
        """Test case for create_workflow_version

        Create a new workflow version  # noqa: E501
        """
        pass

    def test_get_workflow_version(self):
        """Test case for get_workflow_version

        Get the details of a workflow version  # noqa: E501
        """
        pass

    def test_launch_workflow_version(self):
        """Test case for launch_workflow_version

        Launch a workflow version  # noqa: E501
        """
        pass

    def test_list_all_workflow_versions(self):
        """Test case for list_all_workflow_versions

        Get a list of all workflow versions  # noqa: E501
        """
        pass

    def test_list_workflow_versions(self):
        """Test case for list_workflow_versions

        Get a list of workflow versions  # noqa: E501
        """
        pass

    def test_update_workflow_version(self):
        """Test case for update_workflow_version

        Update an existing workflow version  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
