# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libwes
from libica.openapi.libwes.api.workflow_signals_api import WorkflowSignalsApi  # noqa: E501
from libica.openapi.libwes.rest import ApiException


class TestWorkflowSignalsApi(unittest.TestCase):
    """WorkflowSignalsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libwes.api.workflow_signals_api.WorkflowSignalsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_fail_signal(self):
        """Test case for fail_signal

        Fail a workflow signal  # noqa: E501
        """
        pass

    def test_get_signal(self):
        """Test case for get_signal

        Get the details of a workflow signal  # noqa: E501
        """
        pass

    def test_list_signals(self):
        """Test case for list_signals

        Get a list of workflow signals  # noqa: E501
        """
        pass

    def test_succeed_signal(self):
        """Test case for succeed_signal

        Succeed a workflow signal  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
