# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libconsole
from libica.openapi.libconsole.api.tokens_api import TokensApi  # noqa: E501
from libica.openapi.libconsole.rest import ApiException


class TestTokensApi(unittest.TestCase):
    """TokensApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libconsole.api.tokens_api.TokensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_token(self):
        """Test case for create_token

        Creates a JWT token to call IAP services.  # noqa: E501
        """
        pass

    def test_get_token_details(self):
        """Test case for get_token_details

        Get current tokens info require authorization Bearer token  # noqa: E501
        """
        pass

    def test_refresh_token(self):
        """Test case for refresh_token

        Refresh session psToken.  # noqa: E501
        """
        pass

    def test_revoke_token(self):
        """Test case for revoke_token

        Revokes an access token.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
